@@ -8,7 +8,6 @@ from datetime import datetime
 from datetime import time
 from datetime import tzinfo
 from enum import Enum
-from functools import lru_cache
 from typing import TYPE_CHECKING
 from typing import Any
 from typing import Collection
@@ -171,7 +170,9 @@ def item(
     elif isinstance(value, float):
         return Float(value, Trivia(), str(value))
     elif isinstance(value, dict):
-        table_constructor = InlineTable if isinstance(_parent, Array) else Table
+        table_constructor = (
+            InlineTable if isinstance(_parent, (Array, InlineTable)) else Table
+        )
         val = table_constructor(Container(), Trivia(), False)
         for k, v in sorted(
             value.items(),
@@ -185,7 +186,11 @@ def item(
 
         return val
     elif isinstance(value, (list, tuple)):
-        if value and all(isinstance(v, dict) for v in value):
+        if (
+            value
+            and all(isinstance(v, dict) for v in value)
+            and (_parent is None or isinstance(_parent, Table))
+        ):
             a = AoT([])
             table_constructor = Table
         else:
@@ -200,7 +205,7 @@ def item(
                     v.items(),
                     key=lambda i: (isinstance(i[1], dict), i[0] if _sort_keys else 1),
                 ):
-                    i = item(_v, _parent=a, _sort_keys=_sort_keys)
+                    i = item(_v, _parent=table, _sort_keys=_sort_keys)
                     if isinstance(table, InlineTable):
                         i.trivia.trail = ""
 
@@ -242,12 +247,6 @@ def item(
     raise ValueError(f"Invalid type {type(value)}")
 
 
-# This code is only valid for Python < 3.8, when @cached_property was introduced
-# it replaces chained @property and @lru_cache decorators
-def lazy_property(f):
-    return property(lru_cache(maxsize=None)(f))
-
-
 class StringType(Enum):
     # Single Line Basic
     SLB = '"'
@@ -258,13 +257,6 @@ class StringType(Enum):
     # Multi Line Literal
     MLL = "'''"
 
-    def __init__(self, value):
-        self.is_basic = lru_cache(maxsize=None)(self._is_basic)
-        self.is_literal = lru_cache(maxsize=None)(self._is_literal)
-        self.is_singleline = lru_cache(maxsize=None)(self._is_singleline)
-        self.is_multiline = lru_cache(maxsize=None)(self._is_multiline)
-        self.toggle = lru_cache(maxsize=None)(self._toggle)
-
     @classmethod
     def select(cls, literal=False, multiline=False) -> "StringType":
         return {
@@ -298,23 +290,23 @@ class StringType(Enum):
             StringType.MLL: (forbidden_in_literal | {"'''"}) - allowed_in_multiline,
         }[self]
 
-    @lazy_property
+    @property
     def unit(self) -> str:
         return self.value[0]
 
-    def _is_basic(self) -> bool:
+    def is_basic(self) -> bool:
         return self in {StringType.SLB, StringType.MLB}
 
-    def _is_literal(self) -> bool:
+    def is_literal(self) -> bool:
         return self in {StringType.SLL, StringType.MLL}
 
-    def _is_singleline(self) -> bool:
+    def is_singleline(self) -> bool:
         return self in {StringType.SLB, StringType.SLL}
 
-    def _is_multiline(self) -> bool:
+    def is_multiline(self) -> bool:
         return self in {StringType.MLB, StringType.MLL}
 
-    def _toggle(self) -> "StringType":
+    def toggle(self) -> "StringType":
         return {
             StringType.SLB: StringType.MLB,
             StringType.MLB: StringType.SLB,
@@ -327,7 +319,6 @@ class BoolType(Enum):
     TRUE = "true"
     FALSE = "false"
 
-    @lru_cache(maxsize=None)  # noqa: B019
     def __bool__(self):
         return {BoolType.TRUE: True, BoolType.FALSE: False}[self]
 
@@ -518,7 +509,11 @@ class Item:
         """The TOML representation"""
         raise NotImplementedError()
 
-    def unwrap(self):
+    @property
+    def value(self) -> Any:
+        return self
+
+    def unwrap(self) -> Any:
         """Returns as pure python object (ppo)"""
         raise NotImplementedError()
 
@@ -656,7 +651,6 @@ class Integer(int, Item):
         return self._raw
 
     def __add__(self, other):
-
         return self._new(int(self._raw) + other)
 
     def __radd__(self, other):
@@ -1052,7 +1046,7 @@ class Time(Item, time):
 
         self._raw = raw
 
-    def unwrap(self) -> datetime:
+    def unwrap(self) -> time:
         (hour, minute, second, microsecond, tzinfo, _, _) = self._getstate()
         return time(hour, minute, second, microsecond, tzinfo)
 
@@ -1139,7 +1133,8 @@ class Array(Item, _CustomList):
     ) -> None:
         super().__init__(trivia)
         list.__init__(
-            self, [v.value for v in value if not isinstance(v, (Whitespace, Comment))]
+            self,
+            [v.value for v in value if not isinstance(v, (Whitespace, Comment, Null))],
         )
         self._index_map: Dict[int, int] = {}
         self._value = self._group_values(value)
@@ -1172,7 +1167,7 @@ class Array(Item, _CustomList):
         groups.append(this_group)
         return [group for group in groups if group]
 
-    def unwrap(self) -> str:
+    def unwrap(self) -> List[Any]:
         unwrapped = []
         for v in self:
             if isinstance(v, Item):
@@ -1298,7 +1293,14 @@ class Array(Item, _CustomList):
         list.extend(self, data_values)
         if len(self._value) > 0:
             last_item = self._value[-1]
-            last_value_item = next((v for v in self._value[::-1] if v.value), None)
+            last_value_item = next(
+                (
+                    v
+                    for v in self._value[::-1]
+                    if v.value is not None and not isinstance(v.value, Null)
+                ),
+                None,
+            )
             if last_value_item is not None:
                 last_value_item.comma = Whitespace(",")
             if last_item.is_whitespace():
@@ -1435,7 +1437,7 @@ class AbstractTable(Item, _CustomDict):
             if k is not None:
                 dict.__setitem__(self, k.key, v)
 
-    def unwrap(self):
+    def unwrap(self) -> Dict[str, Any]:
         unwrapped = {}
         for k, v in self.items():
             if isinstance(k, Key):
@@ -1517,7 +1519,7 @@ class AbstractTable(Item, _CustomDict):
 
     def __setitem__(self, key: Union[Key, str], value: Any) -> None:
         if not isinstance(value, Item):
-            value = item(value)
+            value = item(value, _parent=self)
 
         is_replace = key in self
         self._value[key] = value
@@ -1581,7 +1583,7 @@ class Table(AbstractTable):
         Appends a (key, item) to the table.
         """
         if not isinstance(_item, Item):
-            _item = item(_item)
+            _item = item(_item, _parent=self)
 
         self._value.append(key, _item)
 
@@ -1692,7 +1694,7 @@ class InlineTable(AbstractTable):
         Appends a (key, item) to the table.
         """
         if not isinstance(_item, Item):
-            _item = item(_item)
+            _item = item(_item, _parent=self)
 
         if not isinstance(_item, (Whitespace, Comment)):
             if not _item.trivia.indent and len(self._value) > 0 and not self._new:
@@ -1783,18 +1785,16 @@ class String(str, Item):
     def as_string(self) -> str:
         return f"{self._t.value}{decode(self._original)}{self._t.value}"
 
-    def __add__(self, other):
+    def __add__(self: ItemT, other: str) -> ItemT:
+        if not isinstance(other, str):
+            return NotImplemented
         result = super().__add__(other)
+        original = self._original + getattr(other, "_original", other)
 
-        return self._new(result)
+        return self._new(result, original)
 
-    def __sub__(self, other):
-        result = super().__sub__(other)
-
-        return self._new(result)
-
-    def _new(self, result):
-        return String(self._t, result, result, self._trivia)
+    def _new(self, result: str, original: str) -> "String":
+        return String(self._t, result, original, self._trivia)
 
     def _getstate(self, protocol=3):
         return self._t, str(self), self._original, self._trivia
@@ -1830,7 +1830,7 @@ class AoT(Item, _CustomList):
         for table in body:
             self.append(table)
 
-    def unwrap(self) -> str:
+    def unwrap(self) -> List[Dict[str, Any]]:
         unwrapped = []
         for t in self._body:
             if isinstance(t, Item):
@@ -1930,7 +1930,7 @@ class Null(Item):
     def __init__(self) -> None:
         pass
 
-    def unwrap(self) -> str:
+    def unwrap(self) -> None:
         return None
 
     @property
